.. _graph:

Graph (class)
=============
Documentation for the graph class.
.. currentmodule:: grakel

.. autosummary::
   :toctree: generated/

   grakel.Graph

.. currentmodule:: grakel.graph

.. autosummary::
   :toctree: generated/

   grakel.graph.is_adjacency
   grakel.graph.is_edge_dictionary
   grakel.graph.laplacian
   grakel.graph.floyd_warshall